#
# $Source: /home/nlfm/Working/Zircon/Released/lib/RCS/Windows.tcl,v $
# $Date: 1998/02/09 16:56:59 $
# $Revision: 1.18.1.5 $
#
# ----------------------------------------------------------------------
#   AUTHOR:  Lindsay Marshall <lindsay.marshall@newcastle.ac.uk>
# ----------------------------------------------------------------------
# Copyright 1996 The University of Newcastle upon Tyne (see COPYRIGHT)
# ======================================================================
#
#
package provide windows 1.18
#
proc tmpdir {} {
    global env zircon
    if {[info exists zircon(tmp)]} { return $zircon(tmp) }
    return $env(TEMP)
}
#
proc prefdir {} { return [file join [glob ~] .zircon] }
#
proc username {} { return {ZirconUser} }
#
